@@ -76,6 +76,7 @@ enum {
 enum {
 	NO_ACTION,
 	SHOW_ACTION,
+	MAYBE_SHOW_ACTION,
 	CLEAR_ACTION,
 	FLAG_ACTION
 };
@@ -898,8 +899,7 @@ static gint gtk_minefield_motion_notify(GtkWidget *widget, GdkEventMotion *event
                         mfield->mines[mfield->cdown].down = 0;
                         gtk_mine_draw(mfield, mfield->cdownx, mfield->cdowny);
 
-                        multi = mfield->multi_mode;
-			if (multi)
+			if (mfield->multi_mode)
 				gtk_minefield_multi_release(mfield, mfield->cdownx,
 				                            mfield->cdowny,
 				                            mfield->cdown, 0);
@@ -909,6 +909,9 @@ static gint gtk_minefield_motion_notify(GtkWidget *widget, GdkEventMotion *event
                         mfield->mines[c].down = 1;
                         gtk_mine_draw(mfield, x, y);
 
+			multi = (mfield->action == MAYBE_SHOW_ACTION) && 
+				mfield->mines[c].shown;
+
 			if (multi)
 				gtk_minefield_multi_press(mfield, x, y, c);
                 }
@@ -966,10 +969,9 @@ static gint gtk_minefield_button_press(GtkWidget *widget, GdkEventButton *event)
 		 * about all the extra legacy crap. */
 		switch (event->button) {
 		case 1:
-			mfield->action = SHOW_ACTION;
+			mfield->action = MAYBE_SHOW_ACTION;
 			if ((event->state & GDK_SHIFT_MASK) ||
-			    (mfield->bdown[2]) ||
-			    mfield->mines[c].shown)
+			    (mfield->bdown[2]))
 				mfield->action = CLEAR_ACTION;
 			break;
 		case 2:
@@ -984,7 +986,9 @@ static gint gtk_minefield_button_press(GtkWidget *widget, GdkEventButton *event)
 
 		/* Now actually do the actions. Most of the real work
 		 * is done in the button_release handler. */
-		if (mfield->action == CLEAR_ACTION) {
+		if ((mfield->action == CLEAR_ACTION) || 
+		    ((mfield->action == MAYBE_SHOW_ACTION) &&
+		     mfield->mines[c].shown)) {
                         gtk_minefield_multi_press(mfield, x, y, c);
                 }
                 else if (mfield->action == FLAG_ACTION && mfield->bdown[2] == 1)
@@ -1013,6 +1017,10 @@ static gint gtk_minefield_button_release(GtkWidget *widget, GdkEventButton *even
 
 	if (mfield->lose || mfield->win) return FALSE;
 
+	if (mfield->action == MAYBE_SHOW_ACTION)
+		mfield->action = mfield->mines[mfield->cdown].shown ? 
+			CLEAR_ACTION : SHOW_ACTION;
+
         if (event->button <= 3 && mfield->bdown[event->button-1]) {
                 switch (mfield->action) {
                 case SHOW_ACTION:
